fauxmo package
==============

Subpackages
-----------

.. toctree::

    fauxmo.plugins

Submodules
----------

fauxmo\.cli module
------------------

.. automodule:: fauxmo.cli
    :members:
    :undoc-members:
    :show-inheritance:

fauxmo\.fauxmo module
---------------------

.. automodule:: fauxmo.fauxmo
    :members:
    :undoc-members:
    :show-inheritance:

fauxmo\.protocols module
------------------------

.. automodule:: fauxmo.protocols
    :members:
    :undoc-members:
    :show-inheritance:

fauxmo\.utils module
--------------------

.. automodule:: fauxmo.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: fauxmo
    :members:
    :undoc-members:
    :show-inheritance:
